'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (props) {

  var theme = (0, _styleHelpers.safeThemeFromProps)(props);

  var _getBandStyle = (0, _styleHelpers.getBandStyle)(theme, props.bandStyle);

  var backgroundColor = _getBandStyle.backgroundColor;
  var textColor = _getBandStyle.textColor;
  var activeColor = _getBandStyle.activeColor;
  var contentStyle = _getBandStyle.contentStyle;
  var itemStyle = _getBandStyle.itemStyle;
  var itemHighlightStyle = _getBandStyle.itemHighlightStyle;
  var logoStyle = _getBandStyle.logoStyle;
  var brandStyle = _getBandStyle.brandStyle;
  var viewport = props.viewport;
  var mode = props.mode;


  var styles = {
    box: {
      position: 'absolute',
      top: 0,
      left: 0,
      width: '100%',
      height: 'auto',
      zIndex: 1000
    },
    boxContent: {
      background: backgroundColor || 'rgba(0,0,0,0)',
      color: textColor,
      padding: '0 5%',
      display: 'flex',
      flexDirection: 'row',
      justifyContent: 'space-between',
      alignItems: 'center'
    },
    logoContainer: {
      margin: 0,
      padding: 0,
      listStyle: 'none',
      flex: '0 1 auto'
    },
    navigationContainer: {
      margin: 0,
      padding: 0,
      listStyle: 'none',
      flex: '0 1 auto',
      textAlign: 'right'
    },
    item: {
      display: 'inline-block',
      padding: '15px',
      fontSize: '16px'
    },
    itemHighlight: {
      display: 'inline-block',
      padding: '7px 12px',
      fontSize: '16px',
      margin: '8px',
      background: activeColor,
      borderRadius: '2px'
    },
    itemLink: {
      color: textColor,
      textDecoration: 'none'
    },
    logo: {
      height: '50px',
      width: 'auto',
      float: 'left'
    },
    brand: {
      fontSize: '18px',
      fontWeight: 'bold',
      lineHeight: '50px',
      display: 'inline-block',
      marginLeft: '10px'
    }
  };

  if (mode === 'FIXED') {
    styles.box.position = 'fixed';
  }

  (0, _lodash.assign)(styles.box, contentStyle || {});
  (0, _lodash.assign)(styles.item, itemStyle || {});
  (0, _lodash.assign)(styles.itemHighlight, itemHighlightStyle || {});
  (0, _lodash.assign)(styles.logo, logoStyle || {});
  (0, _lodash.assign)(styles.brand, brandStyle || {});

  (0, _lodash.assign)(styles.box, props.contentStyle || {});
  (0, _lodash.assign)(styles.item, props.itemStyle || {});
  (0, _lodash.assign)(styles.itemHighlight, props.itemHighlightStyle || {});
  (0, _lodash.assign)(styles.logo, props.logoStyle || {});
  (0, _lodash.assign)(styles.brand, props.brandStyle || {});

  return styles;
};

var _styleHelpers = require('../../utils/styleHelpers');

var _lodash = require('lodash');